pub enum AxisLocation {
Vertex(usize),
Edge(usize, usize),
}Expand description
Variants
Vertex(usize)
The axis passes through the element at this index.
Edge(usize, usize)
The axis passes between the elements at these two consecutive indices.
The invariant j == (i + 1) % n is maintained by
AxisLocation::edge.
Implementations
Sourceimpl AxisLocation
impl AxisLocation
Sourcepub fn edge(i: usize, n: usize) -> Self
pub fn edge(i: usize, n: usize) -> Self
Constructs an Edge between consecutive
elements of a ring of size n, starting at index i.
The second index is computed as (i + 1) % n.
Panics
Panics if n is zero.
Examples
use ring_seq::AxisLocation;
assert_eq!(AxisLocation::edge(2, 3), AxisLocation::Edge(2, 0));
assert_eq!(AxisLocation::edge(0, 4), AxisLocation::Edge(0, 1));Trait Implementations
Sourceimpl Clone for AxisLocation
impl Clone for AxisLocation
Sourcefn clone(&self) -> AxisLocation
fn clone(&self) -> AxisLocation
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AxisLocation
impl Debug for AxisLocation
Sourceimpl Hash for AxisLocation
impl Hash for AxisLocation
Sourceimpl PartialEq for AxisLocation
impl PartialEq for AxisLocation
Sourcefn eq(&self, other: &AxisLocation) -> bool
fn eq(&self, other: &AxisLocation) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for AxisLocation
impl Eq for AxisLocation
impl StructuralPartialEq for AxisLocation