pub type Chunks<'a, T> = Windows<'a, T>;Expand description
Iterator returned by Circular::chunks โ the same shape as
Windows, stepping by the chunk size instead of 1.
Aliased Type
pub struct Chunks<'a, T> { /* private fields */ }pub type Chunks<'a, T> = Windows<'a, T>;Iterator returned by Circular::chunks โ the same shape as
Windows, stepping by the chunk size instead of 1.
pub struct Chunks<'a, T> { /* private fields */ }