AxisLocation

Enum AxisLocation 

pub enum AxisLocation {
    Vertex(usize),
    Edge(usize, usize),
}
A location on a circular sequence where a reflectional-symmetry axis passes.

Variants

  • Vertex — the axis passes through the element at the given index.
  • Edge — the axis passes between two consecutive elements.

Variants



Vertex(usize)

The axis passes through the element at this index.



Edge(usize, usize)

The axis passes between the elements at these two consecutive indices. The invariant j == (i + 1) % n is maintained by AxisLocation::edge.

Implementations

Source

impl AxisLocation

pub fn edge(i: usize, n: usize) -> Self

Constructs an Edge between consecutive elements of a ring of size n, starting at index i.

The second index is computed as (i + 1) % n.

Panics

Panics if n is zero.

Examples
use ring_seq::AxisLocation;

assert_eq!(AxisLocation::edge(2, 3), AxisLocation::Edge(2, 0));
assert_eq!(AxisLocation::edge(0, 4), AxisLocation::Edge(0, 1));